
.. image:: https://pypip.in/download/desktop-security-assistant/badge.png
    :target: https://pypi.python.org/pypi//desktop-security-assistant/
    :alt: Downloads

.. image:: https://pypip.in/version/desktop-security-assistant/badge.png
    :target: https://pypi.python.org/pypi/desktop-security-assistant/
    :alt: Latest Version

.. image:: https://pypip.in/license/desktop-security-assistant/badge.png
    :target: https://pypi.python.org/pypi/desktop-security-assistant/
    :alt: License

Desktop security assistant
==========================

An easy to use tool for desktop users to improve the security of their system.

It scans your Linux desktop or laptop and provide a set of suggestions.


How is it different from security scanners like Tiger?
------------------------------------------------------

* Focused on desktop users rather than servers administrators
* Provides suggestions on every aspect of security: software and hardware configuration and usage
* Hints on risk level and work required to mitigate it

Development status
------------------

In development. Testing and contributions are welcome!

Screenshots 
----------- 
 
.. image:: https://raw.githubusercontent.com/FedericoCeratto/desktop-security-assistant/screenshots/screenshot1.jpg 
 
.. image:: https://raw.githubusercontent.com/FedericoCeratto/desktop-security-assistant/screenshots/screenshot2.jpg 
 
Roadmap
-------

* Implement more checks
